@@ -2,6 +2,48 @@ use serde::{Deserialize, Serialize};
 
 use crate::{Aggregate, AggregateError, DomainEvent};
 
+
+
+
+#[derive(Debug,Serialize,Deserialize,PartialEq,Clone)]
+pub enum MyEvents{
+    SomethingWasDone
+}
+impl DomainEvent for MyEvents {
+    fn event_type(&self) -> &'static str {
+        todo!()
+    }
+    fn event_version(&self) -> &'static str {
+        todo!()
+    }
+}
+#[derive(Debug,Serialize,Deserialize)]
+pub enum  MyCommands {
+    DoSomething,
+    BadCommand,
+}
+#[derive(Debug,Default,Serialize,Deserialize)]
+pub struct MyAggregate;
+impl Aggregate for MyAggregate {
+    type Command = MyCommands;
+    type Event = MyEvents;
+
+    fn aggregate_type() -> &'static str {
+        todo!()
+    }
+
+    fn handle(&self, command: Self::Command) -> Result<Vec<Self::Event>, AggregateError> {
+        match command {
+            MyCommands::DoSomething => Ok(vec![MyEvents::SomethingWasDone]),
+            MyCommands::BadCommand => Err(AggregateError::new("the expected error message")),
+        }
+    }
+
+    fn apply(&mut self, _event: Self::Event) {}
+}
+
+
+
 #[derive(Serialize, Deserialize)]
 pub struct Customer {
     pub customer_id: String,
@@ -19,28 +61,25 @@ impl Aggregate for Customer {
 
     fn handle(&self, command: Self::Command) -> Result<Vec<Self::Event>, AggregateError> {
         match command {
-            CustomerCommand::AddCustomerName(payload) => {
+            CustomerCommand::AddCustomerName{ changed_name } => {
                 if self.name.as_str() != "" {
                     return Err(AggregateError::new(
                         "a name has already been added for this customer",
                     ));
                 }
-                let payload = NameAdded {
-                    changed_name: payload.changed_name,
-                };
-                Ok(vec![CustomerEvent::NameAdded(payload)])
+                Ok(vec![CustomerEvent::NameAdded{ changed_name }])
             }
-            CustomerCommand::UpdateEmail(_) => Ok(Default::default()),
+            CustomerCommand::UpdateEmail{..} => Ok(Default::default()),
         }
     }
 
     fn apply(&mut self, event: Self::Event) {
         match event {
-            CustomerEvent::NameAdded(payload) => {
-                self.name = payload.changed_name;
+            CustomerEvent::NameAdded{ changed_name } => {
+                self.name = changed_name;
             }
-            CustomerEvent::EmailUpdated(payload) => {
-                self.email = payload.new_email;
+            CustomerEvent::EmailUpdated{ new_email } => {
+                self.email = new_email;
             }
         }
     }
@@ -58,25 +97,19 @@ impl Default for Customer {
 
 #[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 pub enum CustomerEvent {
-    NameAdded(NameAdded),
-    EmailUpdated(EmailUpdated),
-}
-
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
-pub struct NameAdded {
-    pub changed_name: String,
-}
-
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
-pub struct EmailUpdated {
-    pub new_email: String,
+    NameAdded{
+        changed_name: String,
+    },
+    EmailUpdated{
+        new_email: String,
+    },
 }
 
 impl DomainEvent for CustomerEvent {
     fn event_type(&self) -> &'static str {
         match self {
-            CustomerEvent::NameAdded(_) => "NameAdded",
-            CustomerEvent::EmailUpdated(_) => "EmailUpdated",
+            CustomerEvent::NameAdded{..} => "NameAdded",
+            CustomerEvent::EmailUpdated{..} => "EmailUpdated",
         }
     }
 
@@ -87,18 +120,12 @@ impl DomainEvent for CustomerEvent {
 
 #[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
 pub enum CustomerCommand {
-    AddCustomerName(AddCustomerName),
-    UpdateEmail(UpdateEmail),
-}
-
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
-pub struct AddCustomerName {
-    pub changed_name: String,
-}
-
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq)]
-pub struct UpdateEmail {
-    pub new_email: String,
+    AddCustomerName{
+        changed_name: String,
+    },
+    UpdateEmail{
+        new_email: String,
+    },
 }
 
 #[cfg(test)]
@@ -113,23 +140,23 @@ mod doc_tests {
     fn test_add_name() {
         CustomerTestFramework::default()
             .given_no_previous_events()
-            .when(CustomerCommand::AddCustomerName(AddCustomerName {
+            .when(CustomerCommand::AddCustomerName {
                 changed_name: "John Doe".to_string(),
-            }))
-            .then_expect_events(vec![CustomerEvent::NameAdded(NameAdded {
+            })
+            .then_expect_events(vec![CustomerEvent::NameAdded {
                 changed_name: "John Doe".to_string(),
-            })]);
+            }]);
     }
 
     #[test]
     fn test_add_name_again() {
         CustomerTestFramework::default()
-            .given(vec![CustomerEvent::NameAdded(NameAdded {
+            .given(vec![CustomerEvent::NameAdded {
                 changed_name: "John Doe".to_string(),
-            })])
-            .when(CustomerCommand::AddCustomerName(AddCustomerName {
+            }])
+            .when(CustomerCommand::AddCustomerName {
                 changed_name: "John Doe".to_string(),
-            }))
+            })
             .then_expect_error("a name has already been added for this customer");
     }
 }
