@@ -71,6 +71,10 @@ where
     pub sequence: usize,
     /// The type of aggregate the event applies to.
     pub aggregate_type: String,
+    /// The type of event.
+    pub event_type: String,
+    /// The event version.
+    pub event_version: String,
     /// The event payload with all business information.
     pub payload: A::Event,
     /// Additional metadata for use in auditing, logging or debugging purposes.
@@ -83,6 +87,8 @@ impl<A: Aggregate> Clone for EventEnvelope<A> {
             aggregate_id: self.aggregate_id.clone(),
             sequence: self.sequence,
             aggregate_type: self.aggregate_type.clone(),
+            event_type: self.event_type.clone(),
+            event_version: self.event_version.clone(),
             payload: self.payload.clone(),
             metadata: self.metadata.clone(),
         }
@@ -102,6 +108,8 @@ impl<A: Aggregate> EventEnvelope<A> {
             aggregate_id,
             sequence,
             aggregate_type,
+            event_type: payload.event_type().to_string(),
+            event_version: payload.event_version().to_string(),
             payload,
             metadata: Default::default(),
         }
@@ -119,6 +127,8 @@ impl<A: Aggregate> EventEnvelope<A> {
             aggregate_id,
             sequence,
             aggregate_type,
+            event_type: payload.event_type().to_string(),
+            event_version: payload.event_version().to_string(),
             payload,
             metadata,
         }
