@@ -1,34 +1,16 @@
 use std::marker::PhantomData;
 
-use crate::aggregate::{Aggregate, AggregateError};
+use crate::aggregate::{Aggregate};
+use crate::AggregateError;
 
 /// A framework for rigorously testing the aggregate logic, one of the ***most important***
-/// parts of any CQRS system.
+/// parts of any DDD system.
 ///
 /// ```
-/// # use cqrs_es::test::TestFramework;
-/// # use cqrs_es::doc::{Customer, CustomerEvent, AddCustomerName, NameAdded, CustomerCommand};
-/// type CustomerTestFramework = TestFramework<Customer>;
+/// # use cqrs_es::doc::MyAggregate;
+/// use cqrs_es::test::TestFramework;
 ///
-/// CustomerTestFramework::default()
-///         .given_no_previous_events()
-///         .when(CustomerCommand::AddCustomerName(AddCustomerName{
-///                 changed_name: "John Doe".to_string()
-///             }))
-///         .then_expect_events(vec![
-///             CustomerEvent::NameAdded(NameAdded{
-///                 changed_name: "John Doe".to_string()
-///             })
-///         ]);
-///
-/// CustomerTestFramework::default()
-///         .given(vec![
-///             CustomerEvent::NameAdded(NameAdded {
-///                 changed_name: "John Doe".to_string()
-///             })
-///         ])
-///         .when(CustomerCommand::AddCustomerName(AddCustomerName{ changed_name: "John Doe".to_string() }))
-///         .then_expect_error("a name has already been added for this customer")
+/// let framework = TestFramework::<MyAggregate>::default();
 /// ```
 pub struct TestFramework<A> {
     _phantom: PhantomData<A>,
@@ -39,11 +21,27 @@ where
     A: Aggregate,
 {
     /// Initiates an aggregate test with no previous events.
+    ///
+    /// ```
+    /// # use cqrs_es::doc::MyAggregate;
+    /// use cqrs_es::test::TestFramework;
+    ///
+    /// let executor = TestFramework::<MyAggregate>::default()
+    ///     .given_no_previous_events();
+    /// ```
     #[must_use]
     pub fn given_no_previous_events(&self) -> AggregateTestExecutor<A> {
         AggregateTestExecutor { events: Vec::new() }
     }
     /// Initiates an aggregate test with a collection of previous events.
+    ///
+    /// ```
+    /// # use cqrs_es::doc::{MyAggregate, MyEvents};
+    /// use cqrs_es::test::TestFramework;
+    ///
+    /// let executor = TestFramework::<MyAggregate>::default()
+    ///     .given(vec![MyEvents::SomethingWasDone]);
+    /// ```
     #[must_use]
     pub fn given(&self, events: Vec<A::Event>) -> AggregateTestExecutor<A> {
         AggregateTestExecutor { events }
@@ -75,6 +73,15 @@ where
 {
     /// Consumes a command and using the state details previously passed provides a validator object
     /// to test against.
+    ///
+    /// ```
+    /// # use cqrs_es::doc::{MyAggregate, MyCommands};
+    /// use cqrs_es::test::TestFramework;
+    ///
+    /// let executor = TestFramework::<MyAggregate>::default().given_no_previous_events();
+    ///
+    /// let validator = executor.when(MyCommands::DoSomething);
+    /// ```
     pub fn when(self, command: A::Command) -> AggregateResultValidator<A> {
         let mut aggregate = A::default();
         for event in self.events {
@@ -95,6 +102,17 @@ where
 
 impl<A: Aggregate> AggregateResultValidator<A> {
     /// Verifies that the expected events have been produced by the command.
+    ///
+    /// ```
+    /// # use cqrs_es::doc::{MyAggregate, MyCommands, MyEvents};
+    /// use cqrs_es::test::TestFramework;
+    ///
+    /// let validator = TestFramework::<MyAggregate>::default()
+    ///     .given_no_previous_events()
+    ///     .when(MyCommands::DoSomething);
+    ///
+    /// validator.then_expect_events(vec![MyEvents::SomethingWasDone]);
+    /// ```
     pub fn then_expect_events(self, expected_events: Vec<A::Event>) {
         let events = match self.result {
             Ok(expected_events) => expected_events,
@@ -105,6 +123,17 @@ impl<A: Aggregate> AggregateResultValidator<A> {
         assert_eq!(&events[..], &expected_events[..]);
     }
     /// Verifies that an `AggregateError` with the expected message is produced with the command.
+    ///
+    /// ```
+    /// # use cqrs_es::doc::{MyAggregate, MyCommands, MyEvents};
+    /// use cqrs_es::test::TestFramework;
+    ///
+    /// let validator = TestFramework::<MyAggregate>::default()
+    ///     .given_no_previous_events()
+    ///     .when(MyCommands::BadCommand);
+    ///
+    /// validator.then_expect_error("the expected error message");
+    /// ```
     pub fn then_expect_error(self, error_message: &str) {
         match self.result {
             Ok(events) => {
